# Библиотека для управления магазином gdshop

Пользовательские объекты для высокоуровневой работы без привязки к слою данных. Предоставляет Python like интерфейс для работы с объектами

## Finance

- [ ] Информация о состоянии счетов
- [ ] Операций с финансами
- [ ] Статистика по финансам за периоды + Прогнозы
- [ ] Расчет и контроль бюджетов
- [ ] Сбор информации с площадок по финансам
- [ ] Генерация отчетов
- [x] Генерация цен по коэфицентам

## Marketing

- [ ] Статистика рекламных компаний
- [ ] Управление рекламными компаниями
- [ ] Статистика воронок
- [ ] Выгрузка информации с площадок
- [ ] Генерация отчетов
- [ ] Статистика по товарам

## Order
- [ ] Получение информации о заказах

## Product
- [x] Получение информации о продукте
- [ ] Обновление содержимого продукта
- [x] Выгрузка информации о товаре в фид
- [ ] Работа с закупками
- [ ] Оценка материалов
- [x] Работа с media
- [x] Работа с description
- [x] Выгрузка меда в S3

## Platform
- [x] Генерация товарных фидов


# Полезные ссылки

## Описание товарного фида

https://yandex.ru/support/partnermarket/export/yml.html
https://drive.google.com/file/d/1kkKa0KU7iNOszyC2oQSGmHNwp3sRGKFb/view